<div>
  <img width="64" src="https://avatars1.githubusercontent.com/u/66532658?s=400&u=f2457dec96897c5dbc843372ec8b325589ab84d5&v=4" alt="cookiecutter-django-rest">
  <h3 >Hello My World</h3>
  <p >
    A simple package make with a cookiecutter
  </p>
  <p>
    <a href="https://www.python.org/">
        <img src="https://img.shields.io/pypi/pyversions/Django.svg?style=flat-square"  alt="python badge">
    </a>
  </p>
</div>

## Demo

Your demo project

## How to Install

With pip

    pip install hello_my_world

## Basic Usage

> Your docs